#line 1 "V3PreLex_pregen.yy.cpp"

#line 3 "V3PreLex_pregen.yy.cpp"

#define  YY_INT_ALIGNED long int

/* A lexical scanner generated by flex */

/* %not-for-header */
/* %if-c-only */
/* %if-not-reentrant */
#define yy_create_buffer V3PreLex_create_buffer
#define yy_delete_buffer V3PreLex_delete_buffer
#define yy_scan_buffer V3PreLex_scan_buffer
#define yy_scan_string V3PreLex_scan_string
#define yy_scan_bytes V3PreLex_scan_bytes
#define yy_init_buffer V3PreLex_init_buffer
#define yy_flush_buffer V3PreLex_flush_buffer
#define yy_load_buffer_state V3PreLex_load_buffer_state
#define yy_switch_to_buffer V3PreLex_switch_to_buffer
#define yypush_buffer_state V3PreLexpush_buffer_state
#define yypop_buffer_state V3PreLexpop_buffer_state
#define yyensure_buffer_stack V3PreLexensure_buffer_stack
#define yy_flex_debug V3PreLex_flex_debug
#define yyin V3PreLexin
#define yyleng V3PreLexleng
#define yylex V3PreLexlex
#define yylineno V3PreLexlineno
#define yyout V3PreLexout
#define yyrestart V3PreLexrestart
#define yytext V3PreLextext
#define yywrap V3PreLexwrap
#define yyalloc V3PreLexalloc
#define yyrealloc V3PreLexrealloc
#define yyfree V3PreLexfree

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
#ifdef yy_create_buffer
#define V3PreLex_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer V3PreLex_create_buffer
#endif

#ifdef yy_delete_buffer
#define V3PreLex_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer V3PreLex_delete_buffer
#endif

#ifdef yy_scan_buffer
#define V3PreLex_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer V3PreLex_scan_buffer
#endif

#ifdef yy_scan_string
#define V3PreLex_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string V3PreLex_scan_string
#endif

#ifdef yy_scan_bytes
#define V3PreLex_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes V3PreLex_scan_bytes
#endif

#ifdef yy_init_buffer
#define V3PreLex_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer V3PreLex_init_buffer
#endif

#ifdef yy_flush_buffer
#define V3PreLex_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer V3PreLex_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define V3PreLex_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state V3PreLex_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define V3PreLex_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer V3PreLex_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define V3PreLexpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state V3PreLexpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define V3PreLexpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state V3PreLexpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define V3PreLexensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack V3PreLexensure_buffer_stack
#endif

#ifdef yylex
#define V3PreLexlex_ALREADY_DEFINED
#else
#define yylex V3PreLexlex
#endif

#ifdef yyrestart
#define V3PreLexrestart_ALREADY_DEFINED
#else
#define yyrestart V3PreLexrestart
#endif

#ifdef yylex_init
#define V3PreLexlex_init_ALREADY_DEFINED
#else
#define yylex_init V3PreLexlex_init
#endif

#ifdef yylex_init_extra
#define V3PreLexlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra V3PreLexlex_init_extra
#endif

#ifdef yylex_destroy
#define V3PreLexlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy V3PreLexlex_destroy
#endif

#ifdef yyget_debug
#define V3PreLexget_debug_ALREADY_DEFINED
#else
#define yyget_debug V3PreLexget_debug
#endif

#ifdef yyset_debug
#define V3PreLexset_debug_ALREADY_DEFINED
#else
#define yyset_debug V3PreLexset_debug
#endif

#ifdef yyget_extra
#define V3PreLexget_extra_ALREADY_DEFINED
#else
#define yyget_extra V3PreLexget_extra
#endif

#ifdef yyset_extra
#define V3PreLexset_extra_ALREADY_DEFINED
#else
#define yyset_extra V3PreLexset_extra
#endif

#ifdef yyget_in
#define V3PreLexget_in_ALREADY_DEFINED
#else
#define yyget_in V3PreLexget_in
#endif

#ifdef yyset_in
#define V3PreLexset_in_ALREADY_DEFINED
#else
#define yyset_in V3PreLexset_in
#endif

#ifdef yyget_out
#define V3PreLexget_out_ALREADY_DEFINED
#else
#define yyget_out V3PreLexget_out
#endif

#ifdef yyset_out
#define V3PreLexset_out_ALREADY_DEFINED
#else
#define yyset_out V3PreLexset_out
#endif

#ifdef yyget_leng
#define V3PreLexget_leng_ALREADY_DEFINED
#else
#define yyget_leng V3PreLexget_leng
#endif

#ifdef yyget_text
#define V3PreLexget_text_ALREADY_DEFINED
#else
#define yyget_text V3PreLexget_text
#endif

#ifdef yyget_lineno
#define V3PreLexget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno V3PreLexget_lineno
#endif

#ifdef yyset_lineno
#define V3PreLexset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno V3PreLexset_lineno
#endif

#ifdef yywrap
#define V3PreLexwrap_ALREADY_DEFINED
#else
#define yywrap V3PreLexwrap
#endif

/* %endif */

#ifdef yyalloc
#define V3PreLexalloc_ALREADY_DEFINED
#else
#define yyalloc V3PreLexalloc
#endif

#ifdef yyrealloc
#define V3PreLexrealloc_ALREADY_DEFINED
#else
#define yyrealloc V3PreLexrealloc
#endif

#ifdef yyfree
#define V3PreLexfree_ALREADY_DEFINED
#else
#define yyfree V3PreLexfree
#endif

/* %if-c-only */

#ifdef yytext
#define V3PreLextext_ALREADY_DEFINED
#else
#define yytext V3PreLextext
#endif

#ifdef yyleng
#define V3PreLexleng_ALREADY_DEFINED
#else
#define yyleng V3PreLexleng
#endif

#ifdef yyin
#define V3PreLexin_ALREADY_DEFINED
#else
#define yyin V3PreLexin
#endif

#ifdef yyout
#define V3PreLexout_ALREADY_DEFINED
#else
#define yyout V3PreLexout
#endif

#ifdef yy_flex_debug
#define V3PreLex_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug V3PreLex_flex_debug
#endif

#ifdef yylineno
#define V3PreLexlineno_ALREADY_DEFINED
#else
#define yylineno V3PreLexlineno
#endif

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* begin standard C++ headers. */
/* %if-c++-only */
/* %endif */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* %not-for-header */
/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */
/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
extern int yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *yyin, *yyout;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */
/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

/* %endif */

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define V3PreLexwrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	(yytext_ptr) -= (yy_more_len); \
	yyleng = (int) (yy_cp - (yytext_ptr)); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;
/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 178
#define YY_END_OF_BUFFER 179
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int32_t yy_accept[696] =
    {   0,
        0,    0,    0,    0,    0,    0,  162,  162,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   34,   34,    0,    0,
       35,   35,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  179,  177,  174,  170,  176,  175,   38,  177,
      171,  177,  177,  171,  171,    4,  174,  176,  177,  150,
      137,  151,  136,  138,  144,  145,  151,  146,  151,  142,
      143,  151,  167,  165,  167,  167,  166,  162,  178,  120,
      118,  120,  120,  119,  120,  100,   91,  102,   90,   94,
       86,   87,  102,  102,   98,  102,   99,  100,   85,   84,

       85,   83,  112,  107,  114,  106,  110,  114,  114,  114,
      178,   29,  178,  133,  132,  131,  133,  125,  133,  123,
      124,  133,  133,  133,  130,  133,  133,   74,   73,   74,
       76,  178,    3,    1,    3,    2,   33,   33,   34,   27,
       25,   26,   26,   27,   27,   27,   27,   27,   35,   71,
       70,   71,   71,   49,   47,   49,   53,   48,   53,   68,
       65,   64,   67,   66,   57,   59,   68,   68,   65,   67,
       68,   41,   39,   41,   45,   40,  178,   82,   78,   77,
       82,   79,   82,   81,  174,  170,    0,    0,  163,  161,
      171,    0,  171,   55,  168,    0,  168,  173,  168,  168,

      168,  168,  168,  171,  171,  174,    0,    0,    0,  168,
      150,  137,    0,    0,  134,  135,  141,  147,    0,  149,
      165,    0,  164,  166,  162,  118,    0,  115,  119,    0,
      117,    0,  100,   91,    0,    0,   88,   89,  101,  101,
       93,    0,   97,    0,   84,    0,  112,  107,    0,    0,
      103,  105,  113,  113,  109,    0,    0,   29,   28,    0,
        0,  132,  131,    0,  126,  128,  121,  122,    0,  130,
      130,  127,   73,    0,   75,    1,    0,    2,    0,   34,
       25,    0,    0,    0,    0,    0,   35,   70,    0,    0,
       47,    0,    0,   48,   52,   52,   50,   52,   65,   64,

        0,   59,    0,   59,   58,   61,    0,   61,   63,   65,
        0,   61,   39,    0,   40,   44,   44,   42,   44,   78,
       77,    0,   80,   46,    0,    0,    0,  160,    0,    0,
      172,  171,  168,    0,  168,  168,  168,  168,  168,  168,
      168,  168,  168,  168,  171,  171,    0,  168,  139,  135,
      147,    0,  147,    0,  116,    0,   95,   89,    0,   92,
        0,    0,  111,  105,  105,    0,  108,    0,    0,  122,
      129,    0,    0,    0,    0,    0,    0,    0,    0,   54,
        0,   51,    0,    0,   60,   61,    0,   61,    0,   61,
       61,    0,   43,    0,    0,    0,    0,  171,  169,  168,

      168,  168,  168,  168,  168,  168,  168,  168,  168,  168,
      168,  171,  171,    0,  168,  148,  140,   96,  104,    0,
        0,    0,    0,    0,    0,   21,    0,    0,    0,    0,
       62,   56,   61,   61,   61,    0,    0,  168,  168,  168,
        7,  168,  168,  168,  168,  168,  168,  168,  168,  168,
      171,  171,    0,  168,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   61,   61,   61,    0,    0,
      168,  168,  168,    8,    9,   17,   10,  168,  168,  168,
      168,   15,  171,  171,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   61,   61,

        0,    0,  168,  168,    6,   11,  168,  168,  168,  168,
       13,   14,    0,    0,    5,    0,   32,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   61,   61,
        0,    0,  168,  168,   12,   31,   31,   30,   31,   31,
      168,  168,    0,   32,    0,    0,    0,   18,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   61,   61,    0,
        0,   36,   37,  168,  168,    0,    0,    0,   18,   18,
        0,    0,    0,    0,    0,    0,    0,    0,   22,    0,
       36,   37,    0,    0,   69,  168,    0,    0,    0,    0,
        0,    0,   19,    0,    0,    0,    0,    0,    0,  168,

        0,    0,   20,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   16,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       72,    0,    0,    0,    0,    0,    0,   24,    0,    0,
        0,   23,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  153,
        0,    0,    0,    0,    0,    0,    0,  152,  153,    0,
        0,    0,    0,  157,    0,    0,  152,    0,  155,  156,
        0,    0,    0,    0,  155,    0,  159,    0,    0,  154,
        0,    0,  154,  158,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    5,    1,    1,    1,    1,
        1,    6,    7,    8,    1,    9,    1,   10,    1,   11,
       12,   13,   14,   15,   16,    1,   17,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,    1,   19,   20,
       21,   22,    1,    1,   23,   23,   23,   23,   24,   25,
       23,   23,   26,   23,   23,   27,   23,   28,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       29,   30,   31,    1,   32,   33,   34,   35,   36,   37,

       38,   39,   40,   41,   42,   23,   43,   44,   45,   46,
       47,   48,   23,   49,   50,   51,   52,   53,   54,   23,
       55,   23,   29,   56,   31,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   57,    1,    1,    1,
       57,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,   57,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[58] =
    {   0,
        1,    2,    3,    4,    1,    2,    1,    5,    6,    1,
        7,    7,    8,    9,   10,    1,   11,   12,    1,    1,
        9,    1,   13,   13,   13,   13,   13,   13,    7,    5,
        7,   14,   15,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,    1,    1
    } ;

static const flex_int32_t yy_base[758] =
    {   0,
        0,   56,   87,  118,  151,    0,   60,   62,  208,    0,
      263,  294,   64,   66,   80,  274,  327,    0,  384,    0,
       83,  286,  441,    0,   58,   71,   68,   75,  497,  549,
       77,  104,  108,  111,  602,    0,  659,  279,  716,    0,
      502,  509, 2248, 2249,  122, 2249,  133, 2249, 2239,  121,
     2213,    0,  766,   63,   40, 2249,  282,  521,  811,    0,
     2249,  136,    0, 2237, 2249, 2249, 2249, 2249,  129, 2249,
     2249,  287, 2249, 2249,  266, 2227,    0,    0, 2249, 2249,
     2249,  269, 2226,    0,  527,    0, 2249,  297,    0, 2234,
     2249, 2249, 2249,  296, 2249,  535, 2249,   95, 2249, 2249,

      315, 2249,    0, 2249,  318,    0, 2233, 2249,  297,  540,
      554, 2249,  544, 2249,  512, 2249,  558, 2249, 2230, 2249,
     2249, 2217,  503, 2222,    0,    0, 2181, 2249, 2249,  560,
     2249,    0, 2249, 2249,  563,    0, 2249, 2187,    0, 2249,
      543, 2249, 2249, 2197, 2200, 2187, 2194, 2193,    0, 2249,
     2249,  565, 2192, 2249, 2249,  567, 2221,    0,  570, 2249,
      573, 2249,  574, 2249, 2249, 2195,    0,  777,  773,  778,
      783, 2249, 2249,  577, 2249,    0,  587, 2249,  592, 2249,
      579, 2249, 2210, 2249,  593, 2249,  593, 2218,  784,  818,
     2192, 2191, 2190, 2249, 2189,    0,  568, 2249,   94,  743,

      784,  745,  476,  552,  110,  827,  832, 2177,  848,  760,
        0, 2249,  797, 2212, 2249,    0, 2249, 2186, 2185, 2249,
     2249,  822, 2249,    0,    0, 2249,  836, 2249,    0,  864,
     2249,  842,    0, 2249,  853, 2209, 2249,    0, 2249,  870,
     2249,  858, 2249, 2183, 2249,  874,    0, 2249,  876, 2207,
     2249, 2184, 2249,  880, 2249,  884,  887, 2249, 2249,  891,
      893,  826, 2249,  895, 2249, 2249, 2249,    0, 2191,    0,
        0, 2249, 2249,  897, 2249, 2249,  899,    0, 2165,    0,
      902, 2171, 2159,  869, 2154, 2159,    0, 2249,  906, 2161,
     2249,  912, 2198,    0, 2249,  915, 2249,  919,  905, 2249,

      921, 2172, 2171, 2170, 2249, 2169, 2168,  894, 2249,  926,
      931,  887, 2249,  935,    0, 2249,  938, 2249,  942,  941,
     2249,  945, 2249, 2249,  948, 2162,  954, 2249,  959, 2161,
     2249, 2165, 2164, 2163, 2162,  941,  825,   26,  918,  836,
      934,  936,  942,  940,  937,  945, 2152,  946, 2249,    0,
     2160, 2159, 2158, 2182, 2249,  979, 2249,    0,  982, 2249,
      987, 2181, 2249, 2158,  992,  996, 2249, 1000, 1002,    0,
     2249, 2136, 2144, 2151,  748, 1005, 2152, 2133, 2145, 2249,
     1011, 2249, 1007, 1015, 2249, 2148, 2147, 2146, 2170,  996,
      987, 1022, 2249, 1027, 1031, 2128, 2127, 2142, 2249,   68,

      779,  994, 1005,  999, 1006,  469,  960, 1007,  802,  880,
     1011, 1009, 1012, 2124, 1017, 2249, 2249, 2249, 2249, 1053,
     2125, 2116, 2108, 2096, 2077, 2249, 2062, 1017, 2061, 2054,
     2249, 2249, 1032, 1033, 1030, 2038, 2031, 1021, 1036, 1034,
     2039, 1037, 1038, 1039, 1040, 1045, 1041, 1042, 1048, 1051,
     1052, 1049, 2005, 1090, 2006, 1996, 1056, 1985, 1950, 1948,
     1909, 1914, 1913, 1898, 1895, 1070, 1067, 1100, 1899, 1898,
     1075, 1081, 1074, 1908, 1895, 1894, 1880, 1076, 1080, 1077,
     1083, 1085, 1087, 1088, 1120, 1126, 1861, 1850, 1853, 1845,
     1836, 1830, 1828, 1827, 1818, 1821, 1825, 1811, 1107, 1111,

     1823, 1810, 1104, 1106, 1810, 1809, 1108, 1146, 1171, 1172,
     1803, 1802, 1203, 1206, 2249, 1211, 1214, 1785, 1786, 1781,
     1769, 1776, 1756, 1770, 1177, 1764, 1219, 1753, 1194, 1196,
     1752, 1740, 1198, 1200, 1757, 2249, 1232, 2249, 1756, 1750,
     1204, 1206, 1242, 1241, 1735, 1745, 1739, 1246, 1745, 1710,
     1704, 1699, 1678, 1667, 1247, 1252, 1662, 1218, 1227, 1652,
     1651, 1660, 1659, 1224, 1229, 1640, 1647, 1642,    0, 1263,
     1644, 1646, 1268, 1636, 1634, 1642, 1263, 1273, 2249, 1621,
     1621, 1618, 1601, 1600, 1594, 1101, 1586, 1278, 1586, 1583,
     1569, 1283, 2249, 1581, 1564, 1286, 1550, 1586, 1585, 1250,

     1554, 1293, 2249, 1543, 1550, 1296, 1538, 1298, 1303, 1548,
     1537, 1536, 1545, 1526, 1524, 1537, 1304, 1306, 1314, 1565,
     1530, 1524, 1523, 1526, 1321, 1287, 1322, 1555, 1554, 1328,
     2249, 1515, 1502, 1510, 1504, 1532, 1330, 2249, 1488, 1487,
     1491, 2249, 1504, 1319, 1311, 1290, 1294, 1302, 1306, 1310,
     1312, 1308, 1297, 1295, 1287, 1308, 1268, 1262, 1274,    0,
     1253, 1248, 1280, 1265, 1256, 1213, 1203,    0,    0, 1168,
     1173, 1129,  999, 2249,  940,  940,    0,  889,    0, 2249,
      843,  862,  830,  734,    0,  521, 2249,  498,  313,    0,
      290,  133,    0, 2249, 2249, 1354, 1369, 1384, 1399, 1414,

     1429, 1444, 1459, 1474, 1489, 1504, 1519, 1529, 1544, 1555,
     1570, 1580, 1584, 1598, 1602, 1616, 1631, 1646, 1661, 1674,
     1682, 1696, 1711, 1715, 1729, 1744, 1748, 1762, 1772, 1787,
     1797, 1801, 1815, 1825, 1840, 1854, 1864, 1879, 1894, 1909,
     1924, 1934, 1949, 1964, 1979, 1994, 2009, 2024, 2039, 2054,
     2069, 2084, 2099, 2114, 2129, 2144, 2159
    } ;

static const flex_int32_t yy_def[758] =
    {   0,
      695,    1,  696,  696,  695,    5,  697,  697,  695,    9,
      698,  698,  699,  699,  700,  700,  695,   17,  695,   19,
      701,  701,  695,   23,  702,  702,  703,  703,  704,  704,
      705,  705,  706,  706,  695,   35,  695,   37,  695,   39,
      707,  707,  695,  695,  695,  695,  695,  695,  695,  695,
      708,  709,  710,  708,  708,  695,  695,  695,  710,  711,
      695,  695,  711,  695,  695,  695,  695,  695,  695,  695,
      695,  712,  695,  695,  695,  695,  713,  714,  695,  695,
      695,  695,  695,  715,  695,  716,  695,  695,  716,  695,
      695,  695,  695,  695,  695,  717,  695,  716,  695,  695,

      695,  695,  718,  695,  695,  718,  695,  695,  695,  719,
      695,  695,  720,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  721,  722,  695,  695,  695,  695,
      695,  723,  695,  695,  695,  724,  695,  695,  725,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  726,  695,
      695,  695,  695,  695,  695,  695,  695,  727,  728,  695,
      695,  695,  695,  695,  695,  729,  730,  731,  695,  695,
      731,  695,  695,  695,  695,  732,  733,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      708,  695,  709,  695,  734,  735,  734,  695,  734,  734,

      734,  734,  734,  708,  708,  695,  695,  695,  695,  734,
      711,  695,  695,  695,  695,  736,  695,  737,  738,  695,
      695,  695,  695,  713,  714,  695,  695,  695,  715,  695,
      695,  695,  716,  695,  695,  695,  695,  739,  695,  695,
      695,  695,  695,  695,  695,  695,  718,  695,  695,  695,
      695,  740,  695,  695,  695,  695,  695,  695,  695,  720,
      695,  695,  695,  695,  695,  695,  695,  741,  695,  721,
      722,  695,  695,  695,  695,  695,  695,  724,  695,  725,
      695,  695,  695,  695,  695,  695,  726,  695,  695,  695,
      695,  695,  695,  727,  695,  695,  695,  695,  695,  695,

      695,  729,  695,  730,  695,  742,  743,  742,  695,  695,
      695,  742,  695,  695,  732,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  709,  734,  695,  735,  734,  734,  734,  734,  734,
      734,  734,  734,  734,  708,  708,  695,  734,  695,  736,
      737,  695,  738,  695,  695,  695,  695,  739,  695,  695,
      695,  695,  695,  740,  740,  695,  695,  695,  695,  741,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  742,  695,  743,  695,  742,
      742,  695,  695,  695,  695,  695,  695,  709,  695,  734,

      734,  734,  734,  734,  734,  734,  734,  734,  734,  734,
      734,  708,  708,  695,  734,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  742,  742,  742,  695,  695,  734,  734,  734,
      734,  734,  734,  734,  734,  734,  734,  734,  734,  734,
      708,  708,  695,  734,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  742,  742,  742,  695,  695,
      734,  734,  734,  734,  734,  734,  734,  734,  734,  734,
      734,  734,  708,  708,  695,  744,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  742,  742,

      695,  695,  734,  734,  734,  734,  734,  695,  734,  734,
      708,  708,  744,  744,  695,  744,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  742,  742,
      695,  695,  734,  734,  734,  695,  745,  695,  734,  695,
      734,  734,  744,  695,  695,  695,  695,  746,  695,  695,
      695,  695,  695,  695,  695,  747,  695,  742,  742,  695,
      695,  734,  734,  734,  734,  695,  695,  695,  746,  746,
      695,  695,  695,  695,  695,  695,  747,  747,  695,  695,
      742,  742,  695,  695,  734,  734,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  734,

      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  734,  695,  695,  695,  695,  695,  695,  748,
      695,  695,  695,  695,  695,  695,  695,  749,  748,  748,
      695,  695,  695,  695,  695,  749,  749,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  750,  695,  695,  695,  751,
      695,  695,  752,  750,  695,  695,  695,  753,  751,  695,
      695,  752,  695,  695,  695,  754,  753,  695,  755,  695,
      695,  754,  695,  695,  755,  695,  695,  695,  756,  757,
      756,  695,  757,  695,    0,  695,  695,  695,  695,  695,

      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695
    } ;

static const flex_int32_t yy_nxt[2307] =
    {   0,
       44,   45,   46,   47,   48,   45,   44,   49,   44,   44,
       44,   44,   44,   44,   44,   44,   50,   44,   44,   44,
       44,   44,   51,   51,   51,   51,   51,   51,   44,   52,
       44,   51,   53,   51,   51,   51,   51,   51,   51,   51,
       51,   54,   51,   55,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   44,   56,   57,  334,   58,
       79,   57,   79,   79,   79,   79,  100,  101,  100,  101,
       79,   79,  192,   79,  102,  403,  102,   79,   79,   79,
       79,  205,  104,  105,  106,  129,  130,  107,   59,   61,
       62,   63,  108,  438,   64,  192,  109,   65,   66,   67,

      334,   68,  243,   69,  131,  138,   79,   79,  204,  110,
      151,  152,  132,  151,  152,   70,   67,   71,  138,   72,
       61,   62,   63,  185,  244,   64,  334,  185,   65,   66,
       67,  337,   68,  189,   69,  186,  187,  190,  212,  213,
      153,  215,  192,  153,  346,  216,   70,   67,   71,  694,
       72,   73,   73,   74,   75,   73,   73,   73,   73,   73,
       73,   73,   73,   76,   73,   73,   73,   73,   77,   73,
       73,   73,   73,   77,   77,   77,   77,   77,   77,   73,
       73,   73,   77,   73,   77,   77,   77,   77,   77,   77,
       77,   77,   77,   77,   77,   77,   77,   77,   77,   77,

       77,   77,   77,   77,   77,   77,   73,   73,   80,   80,
       81,   82,   80,   80,   80,   80,   80,   80,   80,   80,
       83,   80,   80,   80,   80,   84,   80,   80,   80,   80,
       84,   84,   84,   84,   84,   84,   80,   85,   80,   84,
       80,   84,   84,   84,   84,   84,   84,   84,   84,   84,
       84,   84,   84,   84,   84,   84,   84,   84,   84,   84,
       84,   84,   84,   80,   80,   87,   88,   89,  221,  222,
       90,  226,  227,   91,   92,   93,  104,  105,  106,   94,
      169,  107,  170,  206,  169,  207,  108,  206,  129,  130,
      109,   95,   96,   97,  217,   98,   87,   88,   89,  234,

      235,   90,  692,  110,   91,   92,   93,  131,  237,  251,
       94,  171,  238,  252,  208,  132,  219,  245,  246,  220,
      248,  249,   95,   96,   97,  692,   98,   79,  111,  112,
      112,   79,  111,   79,   79,   79,   79,   79,   79,   79,
      113,   79,   79,  113,  113,   79,   79,   79,   79,  113,
      113,  113,  113,  113,  113,   79,   79,   79,   79,   79,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
      113,  113,   79,   79,  114,  115,  116,  117,  114,  115,
      118,  114,  114,  119,  120,  121,  114,  114,  114,  122,

      123,  114,  114,  124,  114,  114,  125,  125,  125,  125,
      125,  125,  114,  126,  114,  125,  114,  125,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  125,  127,
      114,  133,  133,  134,  135,  133,  133,  133,  133,  133,
      133,  133,  133,  133,  133,  133,  133,  133,  136,  133,
      133,  133,  133,  136,  136,  136,  136,  136,  136,  133,
      133,  133,  136,  133,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  133,  133,  141,  142,

      143,  334,  141,  179,  180,  181,  445,  179,  334,  182,
      179,  180,  181,  262,  179,  267,  182,  262,  183,  268,
      184,  344,  207,  186,  209,  183,  207,  184,  230,  231,
      232,  144,  230,  145,  146,  690,  240,  241,  242,  147,
      240,  254,  255,  256,  281,  254,  259,  259,  281,  148,
      141,  142,  143,  208,  141,  257,  258,  258,  689,  257,
      263,  264,  273,  274,  261,  276,  277,  288,  289,  291,
      292,  296,  297,  298,  299,  296,  300,  301,  299,  313,
      314,  321,  322,  144,  192,  145,  146,  345,  317,  318,
      319,  147,  317,  320,  185,  186,  187,  320,  185,  336,

      334,  148,  154,  154,  155,  156,  154,  154,  154,  157,
      154,  154,  154,  154,  154,  154,  154,  154,  154,  158,
      154,  154,  154,  154,  158,  158,  158,  158,  158,  158,
      154,  159,  154,  158,  154,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  158,  158,  158,
      158,  158,  158,  158,  158,  158,  158,  154,  154,  160,
      161,  162,  163,  164,  161,  160,  165,  160,  160,  160,
      160,  160,  160,  160,  160,  160,  160,  160,  160,  160,
      160,  166,  166,  166,  166,  166,  166,  160,  167,  160,
      166,  168,  166,  166,  166,  166,  166,  166,  166,  166,

      166,  166,  166,  166,  166,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  160,  160,  172,  172,  173,  174,
      172,  172,  172,  175,  172,  172,  172,  172,  172,  172,
      172,  172,  172,  176,  172,  172,  172,  172,  176,  176,
      176,  176,  176,  176,  172,  177,  172,  176,  172,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
      176,  176,  176,  176,  176,  176,  176,  176,  176,  176,
      176,  172,  172,  194,  310,  334,  207,  334,  310,  207,
      300,  311,  688,  207,  305,  325,  338,  325,  339,  325,
      305,  340,  334,  343,  424,  196,  425,  197,  198,  212,

      213,  348,  199,  200,  439,  208,  307,  201,  308,  309,
      208,  334,  307,  202,  308,  309,  334,  203,  194,  327,
      328,  329,  341,  327,  221,  222,  312,  262,  206,  342,
      207,  262,  206,  207,  334,  207,  326,  207,  226,  227,
      196,  448,  197,  198,  231,  232,  687,  199,  200,  207,
      186,  209,  201,  207,  210,  234,  235,  334,  202,  208,
      241,  242,  203,  402,  208,  230,  355,  356,  334,  230,
      330,  359,  360,  361,  683,  359,  245,  246,  248,  249,
      208,  366,  367,  368,  405,  366,  255,  256,  257,  258,
      258,  686,  257,  259,  259,  259,  259,  263,  264,  273,

      274,  276,  277,  281,  375,  376,  299,  281,  288,  289,
      299,  261,  334,  369,  291,  292,  381,  382,  383,  387,
      381,  297,  384,  300,  301,  390,  387,  310,  391,  207,
      449,  310,  207,  300,  311,  684,  207,  313,  314,  392,
      393,  394,  320,  392,  318,  395,  320,  321,  322,  325,
      334,  325,  683,  325,  404,  327,  328,  329,  208,  327,
      327,  328,  329,  208,  327,  400,  334,  401,  334,  192,
      406,  408,  334,  334,  334,  409,  411,  192,  334,  407,
      412,  355,  356,  359,  360,  361,  681,  359,  410,  360,
      361,  415,  334,  413,  419,  420,  446,  366,  367,  368,

      326,  366,  367,  368,  259,  259,  330,  426,  426,  382,
      383,  330,  381,  382,  383,  680,  381,  297,  384,  387,
      433,  365,  434,  392,  393,  394,  334,  392,  387,  393,
      394,  334,  435,  318,  395,  440,  427,  334,  334,  334,
      443,  192,  441,  334,  192,  452,  442,  471,  450,  334,
      447,  461,  444,  334,  454,  419,  420,  466,  467,  462,
      451,  463,  387,  472,  387,  387,  334,  468,  334,  334,
      334,  334,  334,  334,  334,  474,  475,  334,  477,  473,
      334,  192,  478,  334,  192,  481,  480,  476,  483,  482,
      489,  486,  479,  486,  500,  486,  499,  484,  503,  387,

      490,  486,  387,  486,  504,  486,  334,  334,  334,  334,
      508,  505,  334,  334,  506,  334,  507,  334,  509,  192,
      192,  486,  334,  486,  511,  486,  510,  514,  515,  516,
      529,  514,  387,  334,  530,  533,  334,  534,  334,  387,
      334,  673,  512,  387,  600,  535,  536,  537,  538,  538,
      536,  537,  536,  536,  539,  536,  536,  536,  536,  536,
      536,  536,  536,  539,  536,  536,  536,  536,  539,  539,
      539,  539,  539,  539,  536,  536,  536,  539,  540,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  539,  539,  539,  539,

      539,  536,  536,  334,  334,  515,  543,  514,  515,  516,
      679,  514,  514,  515,  516,  544,  514,  542,  678,  544,
      555,  541,  552,  553,  555,  558,  387,  559,  387,  562,
      334,  563,  334,  537,  538,  538,  334,  537,  334,  556,
      676,  564,  544,  565,  515,  543,  544,  570,  555,  581,
      387,  570,  555,  578,  579,  579,  334,  578,  582,  387,
      585,  334,  586,  675,  570,  579,  579,  556,  570,  592,
      593,  593,  674,  592,  578,  579,  579,  665,  578,  602,
      603,  603,  334,  602,  592,  593,  593,  608,  592,  426,
      426,  608,  673,  613,  602,  603,  603,  617,  602,  608,

      671,  617,  670,  608,  619,  617,  609,  627,  619,  617,
      620,  627,  668,  628,  667,  619,  618,  666,  609,  619,
      665,  620,  617,  627,  618,  663,  617,  627,  662,  628,
      638,  638,  642,  642,  661,  630,  649,  637,  650,  651,
      652,  618,  653,  654,  655,  658,  659,  657,  606,  648,
      647,  656,  635,  660,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   78,
       78,   78,   78,   78,   78,   78,   78,   78,   78,   78,
       78,   78,   78,   78,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   99,

       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,   99,   99,  103,  103,  103,  103,  103,  103,
      103,  103,  103,  103,  103,  103,  103,  103,  103,  128,
      128,  128,  128,  128,  128,  128,  128,  128,  128,  128,
      128,  128,  128,  128,  137,  137,  137,  137,  137,  137,
      137,  137,  137,  137,  137,  137,  137,  137,  137,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  140,  140,  140,  140,  140,  140,
      140,  140,  140,  140,  140,  140,  140,  140,  140,  149,
      149,  149,  149,  149,  149,  149,  149,  149,  149,  149,

      149,  149,  149,  149,  150,  150,  150,  150,  150,  150,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  178,
      178,  178,  178,  178,  178,  178,  178,  178,  178,  178,
      178,  178,  178,  178,  191,  646,  645,  644,  643,  637,
      191,  191,  191,  191,  193,  641,  626,  640,  193,  193,
      193,  193,  193,  193,  193,  193,  193,  193,  193,  195,
      639,  630,  637,  634,  633,  632,  631,  195,  195,  195,
      211,  211,  630,  626,  625,  211,  624,  334,  211,  623,
      622,  211,  211,  211,  218,  621,  606,  616,  615,  614,
      612,  611,  218,  218,  218,  224,  224,  224,  225,  225,

      610,  607,  225,  225,  225,  225,  225,  225,  225,  225,
      225,  225,  225,  229,  229,  229,  233,  233,  606,  605,
      604,  233,  596,  601,  233,  233,  334,  233,  233,  233,
      233,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  239,  239,  247,  247,  599,  598,
      387,  247,  247,  387,  247,  247,  597,  247,  247,  247,
      247,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  260,  260,  596,  595,
      594,  591,  260,  590,  260,  260,  260,  270,  589,  588,
      587,  334,  334,  270,  270,  270,  271,  584,  583,  580,

      271,  271,  271,  271,  271,  271,  271,  271,  271,  271,
      271,  275,  275,  576,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  278,  278,  278,  280,
      280,  575,  574,  280,  280,  280,  280,  280,  280,  280,
      280,  280,  280,  280,  287,  287,  573,  572,  287,  287,
      287,  287,  287,  287,  287,  287,  287,  287,  287,  294,
      294,  294,  295,  295,  295,  295,  295,  295,  295,  295,
      295,  295,  295,  295,  295,  295,  295,  302,  571,  568,
      567,  566,  399,  302,  302,  302,  302,  304,  334,  334,
      561,  304,  304,  304,  304,  304,  304,  304,  304,  304,

      304,  306,  560,  557,  554,  551,  550,  549,  548,  306,
      306,  306,  315,  315,  315,  316,  316,  316,  316,  316,
      316,  316,  316,  316,  316,  316,  316,  316,  316,  316,
      333,  547,  546,  545,  192,  192,  333,  333,  333,  333,
      335,  334,  334,  532,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  335,  350,  350,  531,  528,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  351,
      527,  526,  525,  524,  523,  351,  351,  351,  351,  353,
      522,  521,  520,  353,  353,  353,  353,  353,  353,  353,
      353,  353,  353,  353,  358,  358,  519,  518,  358,  358,

      358,  358,  358,  358,  358,  358,  358,  358,  358,  364,
      364,  517,  334,  364,  364,  364,  364,  364,  364,  364,
      364,  364,  364,  364,  370,  370,  334,  334,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  386,
      334,  502,  501,  498,  497,  386,  386,  386,  386,  388,
      496,  495,  494,  388,  388,  388,  388,  388,  388,  388,
      388,  388,  388,  388,  513,  513,  513,  513,  513,  513,
      513,  513,  513,  513,  513,  513,  513,  513,  513,  536,
      536,  536,  536,  536,  536,  536,  536,  536,  536,  536,
      536,  536,  536,  536,  569,  569,  493,  492,  569,  569,

      569,  569,  569,  569,  569,  569,  569,  569,  569,  577,
      577,  577,  577,  577,  577,  577,  577,  577,  577,  577,
      577,  577,  577,  577,  629,  629,  491,  488,  629,  629,
      629,  629,  629,  629,  629,  629,  629,  629,  629,  636,
      636,  487,  485,  636,  636,  636,  636,  636,  636,  636,
      636,  636,  636,  636,  664,  664,  664,  664,  664,  664,
      664,  664,  664,  664,  664,  664,  664,  664,  664,  669,
      669,  334,  470,  669,  669,  669,  669,  669,  669,  469,
      669,  669,  669,  669,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  677,

      677,  465,  464,  677,  677,  677,  677,  677,  677,  460,
      677,  677,  677,  677,  682,  682,  682,  682,  682,  682,
      682,  682,  682,  682,  682,  682,  682,  682,  682,  685,
      685,  459,  458,  685,  685,  685,  685,  685,  685,  457,
      685,  685,  685,  685,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  693,
      693,  456,  455,  693,  693,  693,  693,  693,  693,  453,
      693,  693,  693,  693,  398,  437,  436,  432,  387,  431,
      387,  430,  429,  428,  423,  422,  421,  365,  418,  417,
      352,  416,  352,  414,  334,  399,  334,  398,  397,  396,

      389,  387,  303,  385,  303,  380,  379,  378,  377,  374,
      373,  372,  371,  365,  363,  362,  357,  354,  352,  349,
      347,  334,  332,  331,  192,  324,  323,  303,  293,  290,
      286,  285,  284,  283,  282,  279,  272,  269,  266,  265,
      250,  236,  228,  223,  214,  192,  188,  695,   43,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,

      695,  695,  695,  695,  695,  695
    } ;

static const flex_int32_t yy_chk[2307] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    2,  338,    2,
       25,    2,    7,    7,    8,    8,   13,   13,   14,   14,
       27,   27,   55,   26,   13,  338,   14,   28,   28,   31,
       31,   55,   15,   15,   15,   21,   21,   15,    2,    3,
        3,    3,   15,  400,    3,   54,   15,    3,    3,    3,

      400,    3,   98,    3,   21,   25,   32,   32,   54,   15,
       33,   33,   21,   34,   34,    3,    3,    3,   26,    3,
        4,    4,    4,   45,   98,    4,  199,   45,    4,    4,
        4,  199,    4,   50,    4,   47,   47,   50,   62,   62,
       33,   69,  205,   34,  205,   69,    4,    4,    4,  692,
        4,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    5,    5,    5,    5,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,   11,   11,   11,   75,   75,
       11,   82,   82,   11,   11,   11,   16,   16,   16,   11,
       38,   16,   38,   57,   38,   57,   16,   57,   22,   22,
       16,   11,   11,   11,   72,   11,   12,   12,   12,   88,

       88,   12,  691,   16,   12,   12,   12,   22,   94,  109,
       12,   38,   94,  109,   57,   22,   72,  101,  101,   72,
      105,  105,   12,   12,   12,  689,   12,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,

       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   29,   29,

       29,  406,   29,   41,   41,   41,  406,   41,  203,   41,
       42,   42,   42,  115,   42,  123,   42,  115,   41,  123,
       41,  203,   58,   58,   58,   42,   58,   42,   85,   85,
       85,   29,   85,   29,   29,  688,   96,   96,   96,   29,
       96,  110,  110,  110,  141,  110,  113,  113,  141,   29,
       30,   30,   30,   58,   30,  111,  111,  111,  686,  111,
      117,  117,  130,  130,  113,  135,  135,  152,  152,  156,
      156,  159,  159,  159,  161,  159,  163,  163,  161,  174,
      174,  181,  181,   30,  204,   30,   30,  204,  177,  177,
      177,   30,  177,  179,  185,  187,  187,  179,  185,  197,

      197,   30,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,

       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   53,  169,  200,  169,  202,  169,  170,
      170,  170,  684,  170,  168,  189,  200,  189,  200,  189,
      171,  200,  210,  202,  375,   53,  375,   53,   53,  213,

      213,  210,   53,   53,  401,  169,  168,   53,  168,  168,
      170,  401,  171,   53,  171,  171,  201,   53,   59,  190,
      190,  190,  201,  190,  222,  222,  171,  262,  206,  201,
      206,  262,  206,  207,  409,  207,  189,  207,  227,  227,
       59,  409,   59,   59,  232,  232,  683,   59,   59,  209,
      209,  209,   59,  209,   59,  235,  235,  337,   59,  206,
      242,  242,   59,  337,  207,  230,  230,  230,  340,  230,
      190,  240,  240,  240,  682,  240,  246,  246,  249,  249,
      209,  254,  254,  254,  340,  254,  256,  256,  257,  257,
      257,  681,  257,  260,  260,  261,  261,  264,  264,  274,

      274,  277,  277,  281,  284,  284,  299,  281,  289,  289,
      299,  260,  410,  261,  292,  292,  296,  296,  296,  312,
      296,  298,  298,  301,  301,  308,  308,  310,  312,  310,
      410,  310,  311,  311,  311,  678,  311,  314,  314,  317,
      317,  317,  320,  317,  319,  319,  320,  322,  322,  325,
      339,  325,  676,  325,  339,  327,  327,  327,  310,  327,
      329,  329,  329,  311,  329,  336,  341,  336,  342,  345,
      341,  342,  344,  336,  343,  343,  344,  346,  348,  341,
      345,  356,  356,  359,  359,  359,  675,  359,  343,  361,
      361,  348,  407,  346,  365,  365,  407,  366,  366,  366,

      325,  366,  368,  368,  369,  369,  327,  376,  376,  383,
      383,  329,  381,  381,  381,  673,  381,  384,  384,  391,
      390,  365,  390,  392,  392,  392,  402,  392,  390,  394,
      394,  404,  391,  395,  395,  402,  376,  403,  405,  408,
      404,  412,  403,  411,  413,  413,  403,  438,  411,  415,
      408,  428,  405,  438,  415,  420,  420,  433,  434,  428,
      412,  428,  435,  439,  433,  434,  440,  435,  439,  442,
      443,  444,  445,  447,  448,  442,  443,  446,  445,  440,
      449,  452,  446,  450,  451,  449,  448,  444,  451,  450,
      457,  454,  447,  454,  467,  454,  466,  452,  471,  467,

      457,  468,  466,  468,  472,  468,  473,  471,  478,  480,
      480,  473,  479,  472,  478,  481,  479,  482,  481,  483,
      484,  485,  454,  485,  483,  485,  482,  486,  486,  486,
      499,  486,  468,  586,  500,  503,  503,  504,  504,  499,
      507,  672,  484,  500,  586,  507,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,
      508,  508,  508,  508,  508,  508,  508,  508,  508,  508,

      508,  508,  508,  509,  510,  513,  513,  514,  514,  514,
      671,  514,  516,  516,  516,  517,  516,  510,  670,  517,
      527,  509,  525,  525,  527,  529,  529,  530,  530,  533,
      533,  534,  534,  537,  537,  537,  541,  537,  542,  527,
      667,  541,  544,  542,  543,  543,  544,  548,  555,  558,
      558,  548,  555,  556,  556,  556,  564,  556,  559,  559,
      564,  565,  565,  666,  570,  577,  577,  555,  570,  573,
      573,  573,  665,  573,  578,  578,  578,  664,  578,  588,
      588,  588,  600,  588,  592,  592,  592,  596,  592,  626,
      626,  596,  663,  600,  602,  602,  602,  606,  602,  608,

      662,  606,  661,  608,  609,  617,  596,  618,  609,  617,
      609,  618,  659,  618,  658,  619,  606,  657,  608,  619,
      656,  619,  625,  627,  617,  655,  625,  627,  654,  627,
      630,  630,  637,  637,  653,  630,  646,  637,  646,  646,
      647,  625,  647,  647,  649,  651,  652,  650,  648,  645,
      644,  649,  625,  652,  696,  696,  696,  696,  696,  696,
      696,  696,  696,  696,  696,  696,  696,  696,  696,  697,
      697,  697,  697,  697,  697,  697,  697,  697,  697,  697,
      697,  697,  697,  697,  698,  698,  698,  698,  698,  698,
      698,  698,  698,  698,  698,  698,  698,  698,  698,  699,

      699,  699,  699,  699,  699,  699,  699,  699,  699,  699,
      699,  699,  699,  699,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  701,
      701,  701,  701,  701,  701,  701,  701,  701,  701,  701,
      701,  701,  701,  701,  702,  702,  702,  702,  702,  702,
      702,  702,  702,  702,  702,  702,  702,  702,  702,  703,
      703,  703,  703,  703,  703,  703,  703,  703,  703,  703,
      703,  703,  703,  703,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  705,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,

      705,  705,  705,  705,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  707,
      707,  707,  707,  707,  707,  707,  707,  707,  707,  707,
      707,  707,  707,  707,  708,  643,  641,  640,  639,  636,
      708,  708,  708,  708,  709,  635,  634,  633,  709,  709,
      709,  709,  709,  709,  709,  709,  709,  709,  709,  710,
      632,  629,  628,  624,  623,  622,  621,  710,  710,  710,
      711,  711,  620,  616,  615,  711,  614,  613,  711,  612,
      611,  711,  711,  711,  712,  610,  607,  605,  604,  601,
      599,  598,  712,  712,  712,  713,  713,  713,  714,  714,

      597,  595,  714,  714,  714,  714,  714,  714,  714,  714,
      714,  714,  714,  715,  715,  715,  716,  716,  594,  591,
      590,  716,  589,  587,  716,  716,  585,  716,  716,  716,
      716,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  718,  718,  584,  583,
      582,  718,  718,  581,  718,  718,  580,  718,  718,  718,
      718,  719,  719,  719,  719,  719,  719,  719,  719,  719,
      719,  719,  719,  719,  719,  719,  720,  720,  576,  575,
      574,  572,  720,  571,  720,  720,  720,  721,  568,  567,
      566,  563,  562,  721,  721,  721,  722,  561,  560,  557,

      722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
      722,  723,  723,  554,  723,  723,  723,  723,  723,  723,
      723,  723,  723,  723,  723,  723,  724,  724,  724,  725,
      725,  553,  552,  725,  725,  725,  725,  725,  725,  725,
      725,  725,  725,  725,  726,  726,  551,  550,  726,  726,
      726,  726,  726,  726,  726,  726,  726,  726,  726,  727,
      727,  727,  728,  728,  728,  728,  728,  728,  728,  728,
      728,  728,  728,  728,  728,  728,  728,  729,  549,  547,
      546,  545,  540,  729,  729,  729,  729,  730,  539,  535,
      532,  730,  730,  730,  730,  730,  730,  730,  730,  730,

      730,  731,  531,  528,  526,  524,  523,  522,  521,  731,
      731,  731,  732,  732,  732,  733,  733,  733,  733,  733,
      733,  733,  733,  733,  733,  733,  733,  733,  733,  733,
      734,  520,  519,  518,  512,  511,  734,  734,  734,  734,
      735,  506,  505,  502,  735,  735,  735,  735,  735,  735,
      735,  735,  735,  735,  736,  736,  501,  498,  736,  736,
      736,  736,  736,  736,  736,  736,  736,  736,  736,  737,
      497,  496,  495,  494,  493,  737,  737,  737,  737,  738,
      492,  491,  490,  738,  738,  738,  738,  738,  738,  738,
      738,  738,  738,  738,  739,  739,  489,  488,  739,  739,

      739,  739,  739,  739,  739,  739,  739,  739,  739,  740,
      740,  487,  477,  740,  740,  740,  740,  740,  740,  740,
      740,  740,  740,  740,  741,  741,  476,  475,  741,  741,
      741,  741,  741,  741,  741,  741,  741,  741,  741,  742,
      474,  470,  469,  465,  464,  742,  742,  742,  742,  743,
      463,  462,  461,  743,  743,  743,  743,  743,  743,  743,
      743,  743,  743,  743,  744,  744,  744,  744,  744,  744,
      744,  744,  744,  744,  744,  744,  744,  744,  744,  745,
      745,  745,  745,  745,  745,  745,  745,  745,  745,  745,
      745,  745,  745,  745,  746,  746,  460,  459,  746,  746,

      746,  746,  746,  746,  746,  746,  746,  746,  746,  747,
      747,  747,  747,  747,  747,  747,  747,  747,  747,  747,
      747,  747,  747,  747,  748,  748,  458,  456,  748,  748,
      748,  748,  748,  748,  748,  748,  748,  748,  748,  749,
      749,  455,  453,  749,  749,  749,  749,  749,  749,  749,
      749,  749,  749,  749,  750,  750,  750,  750,  750,  750,
      750,  750,  750,  750,  750,  750,  750,  750,  750,  751,
      751,  441,  437,  751,  751,  751,  751,  751,  751,  436,
      751,  751,  751,  751,  752,  752,  752,  752,  752,  752,
      752,  752,  752,  752,  752,  752,  752,  752,  752,  753,

      753,  430,  429,  753,  753,  753,  753,  753,  753,  427,
      753,  753,  753,  753,  754,  754,  754,  754,  754,  754,
      754,  754,  754,  754,  754,  754,  754,  754,  754,  755,
      755,  425,  424,  755,  755,  755,  755,  755,  755,  423,
      755,  755,  755,  755,  756,  756,  756,  756,  756,  756,
      756,  756,  756,  756,  756,  756,  756,  756,  756,  757,
      757,  422,  421,  757,  757,  757,  757,  757,  757,  414,
      757,  757,  757,  757,  398,  397,  396,  389,  388,  387,
      386,  379,  378,  377,  374,  373,  372,  364,  362,  354,
      353,  352,  351,  347,  335,  334,  333,  332,  330,  326,

      307,  306,  304,  303,  302,  293,  290,  286,  285,  283,
      282,  279,  269,  252,  250,  244,  236,  219,  218,  214,
      208,  195,  193,  192,  191,  188,  183,  166,  157,  153,
      148,  147,  146,  145,  144,  138,  127,  124,  122,  119,
      107,   90,   83,   76,   64,   51,   49,   43,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,

      695,  695,  695,  695,  695,  695
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 1;

static const flex_int32_t yy_rule_linenum[178] =
    {   0,
      109,  110,  111,  114,  115,  117,  118,  119,  120,  121,
      122,  123,  124,  125,  126,  127,  128,  132,  160,  165,
      171,  172,  177,  182,  188,  189,  192,  195,  210,  217,
      225,  230,  232,  237,  242,  246,  251,  258,  261,  263,
      264,  265,  266,  267,  268,  275,  278,  279,  280,  281,
      282,  283,  284,  285,  292,  295,  296,  297,  298,  299,
      300,  301,  302,  303,  304,  305,  306,  307,  310,  313,
      314,  315,  320,  322,  323,  324,  327,  328,  329,  330,
      331,  332,  336,  338,  340,  343,  344,  347,  348,  349,
      352,  353,  354,  355,  356,  357,  358,  359,  360,  361,

      362,  363,  366,  367,  368,  369,  371,  372,  373,  374,
      375,  376,  377,  378,  383,  384,  385,  388,  390,  391,
      398,  399,  400,  401,  402,  403,  404,  405,  406,  407,
      408,  409,  410,  413,  414,  415,  418,  419,  420,  421,
      422,  423,  424,  425,  439,  445,  450,  451,  452,  453,
      454,  457,  458,  459,  460,  461,  462,  463,  464,  467,
      468,  469,  473,  474,  475,  478,  479,  483,  484,  487,
      489,  490,  491,  492,  493,  494,  495
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
static int yy_more_flag = 0;
static int yy_more_len = 0;
#define yymore() ((yy_more_flag) = 1)
#define YY_MORE_ADJ (yy_more_len)
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../V3PreLex.l"
/**************************************************************************
 * DESCRIPTION: Verilator: Flex verilog preprocessor
 *
 * Code available from: https://verilator.org
 *
 **************************************************************************
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of either the GNU Lesser General Public License Version 3
 * or the Perl Artistic License Version 2.0.
 * SPDX-FileCopyrightText: 2003-2026 Wilson Snyder
 * SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 *
 **************************************************************************
 * Do not use Flex in C++ mode.  It has bugs with yyunput() which result in
 * lost characters.
 **************************************************************************/
/* clang-format off */
#line 25 "../V3PreLex.l"
#ifdef NEVER_JUST_FOR_CLANG_FORMAT
 }
#endif

#include "V3PreProc.h"
#include "V3PreLex.h"
#ifdef _WIN32
# include <io.h> // for isatty
#endif

/* clang-format on */

V3PreLex* V3PreLex::s_currentLexp = nullptr;  // Current lexing point

#define LEXP V3PreLex::s_currentLexp

#define YY_INPUT(buf, result, max_size) \
    do { result = LEXP->inputToLex(buf, max_size); } while (false)

// Accessors, because flex keeps changing the type of yyleng
char* yyourtext() { return yytext; }
size_t yyourleng() { return yyleng; }
void yyourtext(const char* textp, size_t size) {
    yytext = (char*)textp;
    yyleng = size;
}

// FL_FWD only tracks columns; preproc uses linenoInc() to track lines, so
// insertion of a \n does not mess up line count
#define FL_FWDC (LEXP->curFilelinep()->forwardToken(yytext, yyleng, false))
// Use this to break between tokens whereever not return'ing a token (e.g. skipping inside lexer)
#define FL_BRK (LEXP->curFilelinep()->startToken())

static void linenoInc() { LEXP->linenoInc(); }
static bool pedantic() { return LEXP->m_pedantic; }
static void yyerror(const char* msg) { LEXP->curFilelinep()->v3error(msg); }
static void yyerrorf(const char* msg) { LEXP->curFilelinep()->v3error(msg); }
static void appendDefValue(const char* t, size_t l) { LEXP->appendDefValue(t, l); }

/* clang-format off */
/**********************************************************************/
#line 1617 "V3PreLex_pregen.yy.cpp"

/* drop: Drop Ctrl-Z - can't pass thru or may EOF the output too soon */
/* Where we use symb/symbdef, we must also look for a `` join */
/* Note in the preprocessor \ESCaped is *not* always special; mantis1537/bug441 */
#line 106 "../V3PreLex.l"
        /**************************************************************/
#line 1624 "V3PreLex_pregen.yy.cpp"

#define INITIAL 0
#define ARGMODE 1
#define CMTMODE 2
#define CMTONEM 3
#define DEFCMT 4
#define DEFFORM 5
#define DEFFPAR 6
#define DEFVAL 7
#define ENCBASE64 8
#define EXPR 9
#define INCMODE 10
#define PASSTHRU 11
#define PRAGMA 12
#define PRAGMAERR 13
#define PRAGMAPRT 14
#define PRAGMAPRTERR 15
#define PRTMODE 16
#define QQQMODE 17
#define STRIFY 18
#define STRMODE 19
#define LIBMODE 20

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int yy_init_globals ( void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

/* %not-for-header */
#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state ( int _new_state );
    
    static void yy_pop_state ( void );
    
    static int yy_top_state ( void );
    
/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */
/* %ok-for-header */

/* %not-for-header */
/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int yylex (void);

#define YY_DECL int yylex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/* %not-for-header */
/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
/* %% [7.0] user's declarations go here */
#line 107 "../V3PreLex.l"

        /* Passthru, to support dev-coverage of some main verilog.l rules */
#line 1940 "V3PreLex_pregen.yy.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		(yy_more_len) = 0;
		if ( (yy_more_flag) )
			{
			(yy_more_len) = (int) ((yy_c_buf_p) - (yytext_ptr));
			(yy_more_flag) = 0;
			}
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 696 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2249 );

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 178 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 178 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 179 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 109 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yytext=(char*)"\n"; yyleng=1; return VP_WHITE; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 110 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 111 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
/* Special directives we recognize */
case 4:
YY_RULE_SETUP
#line 114 "../V3PreLex.l"
{ }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 115 "../V3PreLex.l"
{ FL_FWDC; LEXP->lineDirective(yytext);
                                                  return VP_LINE; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 117 "../V3PreLex.l"
{ FL_FWDC; return VP_DEFINE; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 118 "../V3PreLex.l"
{ FL_FWDC; return VP_ELSE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 119 "../V3PreLex.l"
{ FL_FWDC; return VP_ELSIF; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 120 "../V3PreLex.l"
{ FL_FWDC; return VP_ENDIF; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 121 "../V3PreLex.l"
{ FL_FWDC; return VP_IFDEF; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 122 "../V3PreLex.l"
{ FL_FWDC; return VP_IFNDEF; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 123 "../V3PreLex.l"
{ FL_FWDC; return VP_INCLUDE; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 124 "../V3PreLex.l"
{ FL_FWDC; yy_push_state(LIBMODE); return VP_TEXT; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 125 "../V3PreLex.l"
{ FL_FWDC; yy_push_state(LIBMODE); return VP_TEXT; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 126 "../V3PreLex.l"
{ FL_FWDC; return VP_UNDEF; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 127 "../V3PreLex.l"
{ FL_FWDC; return VP_UNDEFINEALL; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 128 "../V3PreLex.l"
{ FL_FWDC; if (!pedantic()) return VP_ERROR; else return VP_DEFREF; }
	YY_BREAK
/* We wanted this to be next to `protect But it must be before `pramga */
/* we win only because we both match to the end of the line so the length */
/* is equal and we are first*/
case 18:
YY_RULE_SETUP
#line 132 "../V3PreLex.l"
{ FL_FWDC;
                          int res;
                          char enctype[16]; // long enough to hold "quote-printable"
                          if (LEXP->m_protBytes > 0) {
                              LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "Multiple `pragma protected encoding sections");
                          }
                          res = sscanf(yytext + std::strlen("encoding"), " = (enctype = \"%15[A-Za-z0-9]\", line_length = %d, bytes = %d)", &enctype[0], &LEXP->m_protLength, &LEXP->m_protBytes);
                          if (res == 0)
                              LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "`pragma protected encoding must have an \"enctype\" field");
                          LEXP->m_encType = !VL_STRCASECMP(enctype, "uuencode") ? Enctype::UUENCODE :
                                            !VL_STRCASECMP(enctype, "base64") ? Enctype::BASE64 :
                                            !VL_STRCASECMP(enctype, "quoted-printable") ? Enctype::QUOTE_PRINTABLE :
                                            !VL_STRCASECMP(enctype, "raw") ? Enctype::RAW : Enctype::ERR;
                          if (LEXP->m_encType == Enctype::ERR)
                              LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "Illegal encoding type for `pragma protected encoding");
                          if (LEXP->m_encType != Enctype::BASE64)
                              LEXP->curFilelinep()->v3warn(E_UNSUPPORTED, "Unsupported: only BASE64 is recognized for `pragma protected encoding");
                          if (res == 3) {
                              if ((LEXP->m_encType == Enctype::BASE64) && (LEXP->m_protLength & 3))
                                  LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "line_length must be multiple of 4 for BASE64");
                          } else {
                              // default values
                              LEXP->m_protBytes = 0;
                              LEXP->m_protLength = 76; // ?? default value not mentioned in IEEE spec
                          }
                          BEGIN(INITIAL);
                          return VP_TEXT;
                        }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 160 "../V3PreLex.l"
{
                          FL_FWDC;
                          linenoInc();
                          BEGIN(ENCBASE64);
                          return VP_TEXT; }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 165 "../V3PreLex.l"
{
                          FL_FWDC;
                          linenoInc();
                          LEXP->curFilelinep()->v3warn(PROTECTED, "A '`pragma protected data_block' encrypted section was detected and will be skipped.");
                          BEGIN(ENCBASE64);
                          return VP_TEXT; }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 171 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); BEGIN(INITIAL); return VP_TEXT; }
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 172 "../V3PreLex.l"
{
                          FL_FWDC;
                          linenoInc();
                          BEGIN(INITIAL);
                          return VP_TEXT; }
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 177 "../V3PreLex.l"
{
                          FL_FWDC;
                          linenoInc();
                          BEGIN(INITIAL);
                          return VP_TEXT; }
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 182 "../V3PreLex.l"
{
                          FL_FWDC;
                          linenoInc();
                          BEGIN(INITIAL);
                          return VP_TEXT; }
	YY_BREAK
/* end of `pragma protect */
case 25:
YY_RULE_SETUP
#line 188 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 189 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); BEGIN(INITIAL); return VP_TEXT; }
	YY_BREAK
/* catch-all for unknown '`pragma protect' rules */
case 27:
YY_RULE_SETUP
#line 192 "../V3PreLex.l"
{ yyless(0);
                          BEGIN(PRAGMAPRTERR);
                          return VP_TEXT; }
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 195 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); FL_BRK;
                          if ((yyourleng()-1) <= size_t(LEXP->m_protLength) && ((yyleng & 3) == 1)) {
                              LEXP->m_protBytes -= (yyleng-1)/4*3;
                          } else {
                              LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "BASE64 line too long in `pragma protect key_block/data_block");
                          }
                          if (yytext[yyleng-3] == '=')
                              LEXP->m_protBytes++;
                          if (yytext[yyleng-2] == '=')
                              LEXP->m_protBytes++;
                          if (LEXP->m_protBytes == 0) {
                              BEGIN(INITIAL);
                          } else if (LEXP->m_protBytes < 0)
                              LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "BASE64 encoding (too short) in `pragma protect key_block/data_block");
                          /*return VP_TEXT;*/ }
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 210 "../V3PreLex.l"
{ FL_FWDC;
                          if (LEXP->m_protBytes != 0)
                              LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "BASE64 encoding length mismatch in `pragma protect key_block/data_block");
                          linenoInc(); BEGIN(INITIAL);
                          return VP_TEXT; }
	YY_BREAK
/* Catch only empty `pragma lines */
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 217 "../V3PreLex.l"
{
                          yyless(yyleng - 1); FL_FWDC;
                          if (v3Global.opt.pedantic()) {
                              LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "`pragma is missing a pragma_expression.");
                          }
                          return VP_TEXT; }
	YY_BREAK
/* catch all other nonempty `pragma */
case 31:
YY_RULE_SETUP
#line 225 "../V3PreLex.l"
{
                          yyless(yyleng - 1); FL_FWDC;
                          if (!v3Global.opt.preprocOnly())
                              BEGIN(PRAGMA);
                          return VP_TEXT; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 230 "../V3PreLex.l"
{ FL_FWDC; BEGIN(PRAGMAPRT); return VP_TEXT;}
	YY_BREAK
/* catch-all for unknown `pragma rules */
case 33:
YY_RULE_SETUP
#line 232 "../V3PreLex.l"
{ yyless(0);
                          BEGIN(PRAGMAERR);
                          return VP_TEXT; }
	YY_BREAK
/* the catch-all rule only got 1 char, lets get all line */
case 34:
YY_RULE_SETUP
#line 237 "../V3PreLex.l"
{ FL_FWDC;
                          /* Add a warning here for unknown pragmas if desired, at the moment , we don't */
                          /* LEXP->curFilelinep()->v3warn(BADPRAGMA, "Unknown `pragma"); */
                          BEGIN(INITIAL);
                          return VP_TEXT; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 242 "../V3PreLex.l"
{ FL_FWDC;
                          LEXP->curFilelinep()->v3warn(BADSTDPRAGMA, "Unknown '`pragma protect' error");
                          BEGIN(INITIAL);
                          return VP_TEXT; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 246 "../V3PreLex.l"
{ FL_FWDC;
                          static string s_rtnfile;
                          s_rtnfile = '"'; s_rtnfile += LEXP->curFilelinep()->filenameEsc();
                          s_rtnfile += '"'; yytext = (char*)s_rtnfile.c_str(); yyleng = s_rtnfile.length();
                          return VP_STRING; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 251 "../V3PreLex.l"
{ FL_FWDC;
                          static char s_buf[25];
                          (void)VL_SNPRINTF(s_buf, 25, "%d", LEXP->curFilelinep()->lastLineno());
                          yytext = s_buf; yyleng = std::strlen(yytext);
                          return VP_TEXT; }
	YY_BREAK
/* Pass-through strings */
case 38:
YY_RULE_SETUP
#line 258 "../V3PreLex.l"
{ yy_push_state(STRMODE); yymore(); }
	YY_BREAK
case YY_STATE_EOF(STRMODE):
#line 259 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yyerrorf("EOF in unterminated string");
                          yyleng=0; return VP_EOF_ERROR; }
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 261 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yyerrorf("Unterminated string");
                          FL_BRK; BEGIN(INITIAL); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 263 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 41:
/* rule 41 can match eol */
YY_RULE_SETUP
#line 264 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
#line 265 "../V3PreLex.l"
{ linenoInc(); yymore(); }
	YY_BREAK
case 43:
/* rule 43 can match eol */
YY_RULE_SETUP
#line 266 "../V3PreLex.l"
{ LEXP->warnBackslashSpace(); yyless(1); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 267 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 268 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state();
                          if (LEXP->m_parenLevel || LEXP->m_defQuote) {
                              LEXP->m_defQuote=false; appendDefValue(yytext, yyleng);
                              yyleng=0; FL_BRK;
                          } else return VP_STRING; }
	YY_BREAK
/* Pass-through quote-quote-quote */
case 46:
YY_RULE_SETUP
#line 275 "../V3PreLex.l"
{ yy_push_state(QQQMODE); yymore(); }
	YY_BREAK
case YY_STATE_EOF(QQQMODE):
#line 276 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yyerrorf("EOF in unterminated \"\"\" string");
                          yyleng=0; return VP_EOF_ERROR; }
	YY_BREAK
case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
#line 278 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yymore(); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 279 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 49:
/* rule 49 can match eol */
YY_RULE_SETUP
#line 280 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 50:
/* rule 50 can match eol */
YY_RULE_SETUP
#line 281 "../V3PreLex.l"
{ linenoInc(); yymore(); }
	YY_BREAK
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
#line 282 "../V3PreLex.l"
{ LEXP->warnBackslashSpace(); yyless(1); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 283 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 284 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 285 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state();
                          if (LEXP->m_parenLevel || LEXP->m_defQuote) {
                              LEXP->m_defQuote=false; appendDefValue(yytext, yyleng);
                              yyleng=0; FL_BRK;
                          } else return VP_STRING; }
	YY_BREAK
/* Stringification */
case 55:
YY_RULE_SETUP
#line 292 "../V3PreLex.l"
{ FL_FWDC; yy_push_state(STRIFY); return VP_STRIFY; }
	YY_BREAK
case YY_STATE_EOF(STRIFY):
#line 293 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yyerrorf("EOF in unterminated '\"");
                          yyleng=0; return VP_EOF_ERROR; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 295 "../V3PreLex.l"
{ FL_FWDC; return VP_BACKQUOTE; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 296 "../V3PreLex.l"
{ yy_push_state(STRMODE); yymore(); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 297 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); return VP_STRIFY; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 298 "../V3PreLex.l"
{ FL_FWDC; return VP_SYMBOL; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 299 "../V3PreLex.l"
{ FL_FWDC; yyleng-=2; return VP_SYMBOL_JOIN; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 300 "../V3PreLex.l"
{ FL_FWDC; return VP_DEFREF; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 301 "../V3PreLex.l"
{ FL_FWDC; yyleng-=2; return VP_DEFREF_JOIN; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 302 "../V3PreLex.l"
{ FL_FWDC; yyleng-=2; return VP_JOIN; }
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
#line 303 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yytext = (char*)"\n"; yyleng = 1; return VP_WHITE; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 304 "../V3PreLex.l"
{ FL_FWDC; return VP_WHITE; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 305 "../V3PreLex.l"
{ FL_FWDC; FL_BRK; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 306 "../V3PreLex.l"
{ FL_FWDC; FL_BRK; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 307 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
/* Protected blocks */
case 69:
YY_RULE_SETUP
#line 310 "../V3PreLex.l"
{ yy_push_state(PRTMODE); yymore(); }
	YY_BREAK
case YY_STATE_EOF(PRTMODE):
#line 311 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yyerrorf("EOF in `protected");
                          yyleng = 0; return VP_EOF_ERROR; }
	YY_BREAK
case 70:
/* rule 70 can match eol */
YY_RULE_SETUP
#line 313 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); return VP_TEXT; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 314 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 315 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); return VP_TEXT; }
	YY_BREAK
/* Pass-through include <> filenames */
case YY_STATE_EOF(INCMODE):
#line 318 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yyerrorf("EOF in unterminated include filename");
                          yyleng = 0; return VP_EOF_ERROR; }
	YY_BREAK
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
#line 320 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yyerrorf("Unterminated include filename");
                          FL_BRK; BEGIN(INITIAL); }
	YY_BREAK
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
#line 322 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 323 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 324 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); return VP_STRING; }
	YY_BREAK
/* Library/config file paths */
case 77:
/* rule 77 can match eol */
YY_RULE_SETUP
#line 327 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yytext=(char*)"\n"; yyleng=1; return VP_WHITE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 328 "../V3PreLex.l"
{ FL_FWDC; return VP_WHITE; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 329 "../V3PreLex.l"
{ yy_push_state(STRMODE); yymore(); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 330 "../V3PreLex.l"
{ yy_push_state(CMTONEM); yymore(); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 331 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); return VP_TEXT; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 332 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
/* Reading definition formal parenthesis (or not) to begin formal arguments */
/* Note '(' must IMMEDIATELY follow definition name */
case 83:
YY_RULE_SETUP
#line 336 "../V3PreLex.l"
{ FL_FWDC; appendDefValue("(", 1); LEXP->m_formalLevel=1;
                          FL_BRK; BEGIN(DEFFORM); }
	YY_BREAK
case 84:
/* rule 84 can match eol */
YY_RULE_SETUP
#line 338 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); unput('\n'); yyleng=0; return VP_DEFFORM; }  /* DEFVAL will later grab the return */
	YY_BREAK
case YY_STATE_EOF(DEFFPAR):
#line 339 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); return VP_DEFFORM; }  /* empty formals */
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 340 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); unput(yytext[yyleng-1]); yyleng=0; return VP_DEFFORM; }  /* empty formals */
	YY_BREAK
/* Reading definition formals (declaration of a define) */
case 86:
YY_RULE_SETUP
#line 343 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; yyleng=0; ++LEXP->m_formalLevel; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 344 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); yyleng=0;
                          if ((--LEXP->m_formalLevel)==0) { yy_pop_state(); return VP_DEFFORM; }
                          FL_BRK; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 347 "../V3PreLex.l"
{ yy_push_state(CMTMODE); yymore(); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 348 "../V3PreLex.l"
{ FL_FWDC; return VP_COMMENT;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 349 "../V3PreLex.l"
{ FL_FWDC; FL_BRK; }
	YY_BREAK
case YY_STATE_EOF(DEFFORM):
#line 350 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yy_pop_state(); yyerrorf("Unterminated ( in define formal arguments.");
                          yyleng=0; return VP_DEFFORM; }
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 352 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); appendDefValue((char*)"\n", 1); FL_BRK; }  /* Include return so can maintain output line count */
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 353 "../V3PreLex.l"
{ LEXP->warnBackslashSpace(); yyless(1); }
	YY_BREAK
case 93:
/* rule 93 can match eol */
YY_RULE_SETUP
#line 354 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); appendDefValue((char*)"\\\n", 2); FL_BRK; }  /* Include return so can maintain output line count */
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 355 "../V3PreLex.l"
{ LEXP->m_defQuote=true; yy_push_state(STRMODE); yymore(); }  /* Legal only in default values */
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 356 "../V3PreLex.l"
{ LEXP->m_defQuote=true; yy_push_state(QQQMODE); yymore(); }  /* Legal only in default values */
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 357 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }  /* Maybe illegal, otherwise in default value */
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 358 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }  /* Maybe illegal, otherwise in default value */
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 359 "../V3PreLex.l"
{ FL_FWDC; LEXP->m_formalLevel++; appendDefValue(yytext, yyleng); FL_BRK; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 360 "../V3PreLex.l"
{ FL_FWDC; LEXP->m_formalLevel--; appendDefValue(yytext, yyleng); FL_BRK; }
	YY_BREAK
case 100:
#line 362 "../V3PreLex.l"
case 101:
#line 363 "../V3PreLex.l"
case 102:
YY_RULE_SETUP
#line 363 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }
	YY_BREAK
/* Reading definition value (declaration of a define's text) */
case 103:
YY_RULE_SETUP
#line 366 "../V3PreLex.l"
{ LEXP->m_defCmtSlash=false; yy_push_state(DEFCMT); yymore(); }  /* Special comment parser */
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
#line 367 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); appendDefValue((char*)"\n", 1); FL_BRK; }  /* Spec says // not part of define value */
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 368 "../V3PreLex.l"
{ FL_FWDC; return VP_COMMENT;}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 369 "../V3PreLex.l"
{ FL_FWDC; FL_BRK; }
	YY_BREAK
case YY_STATE_EOF(DEFVAL):
#line 370 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yy_pop_state(); yytext=(char*)"\n"; yyleng=1; return VP_DEFVALUE; }  /* Technically illegal, but people complained */
	YY_BREAK
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
#line 371 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yy_pop_state(); yytext=(char*)"\n"; yyleng=1; return VP_DEFVALUE; }
	YY_BREAK
case 108:
/* rule 108 can match eol */
YY_RULE_SETUP
#line 372 "../V3PreLex.l"
{ LEXP->warnBackslashSpace(); yyless(1); }
	YY_BREAK
case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
#line 373 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); appendDefValue((char*)"\\\n", 2); FL_BRK; }  /* Return, AND \ is part of define value */
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 374 "../V3PreLex.l"
{ LEXP->m_defQuote = true; yy_push_state(STRMODE); yymore(); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 375 "../V3PreLex.l"
{ LEXP->m_defQuote = true; yy_push_state(QQQMODE); yymore(); }
	YY_BREAK
case 112:
#line 377 "../V3PreLex.l"
case 113:
#line 378 "../V3PreLex.l"
case 114:
YY_RULE_SETUP
#line 378 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }
	YY_BREAK
/* Comments inside define values - if embedded get added to define value per spec */
/* - if no \{crnl} ending then the comment belongs to the next line, as a non-embedded comment */
/* - if all but (say) 3rd line is missing \ then it's indeterminate */
case 115:
YY_RULE_SETUP
#line 383 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); appendDefValue(yytext, yyleng); FL_BRK; }
	YY_BREAK
case 116:
/* rule 116 can match eol */
YY_RULE_SETUP
#line 384 "../V3PreLex.l"
{ LEXP->warnBackslashSpace(); yyless(1); }
	YY_BREAK
case 117:
/* rule 117 can match eol */
YY_RULE_SETUP
#line 385 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); LEXP->m_defCmtSlash=true;
                          appendDefValue(yytext, yyleng-2); appendDefValue((char*)"\n", 1);  /* Return but not \ */
                          FL_BRK; }
	YY_BREAK
case 118:
/* rule 118 can match eol */
YY_RULE_SETUP
#line 388 "../V3PreLex.l"
{ linenoInc(); yymore(); if (LEXP->m_defCmtSlash) yyerrorf("One line of /* ... */ is missing \\ before newline");
                          BEGIN(CMTMODE); }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 390 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 391 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case YY_STATE_EOF(DEFCMT):
#line 392 "../V3PreLex.l"
{ FL_FWDC; yyerrorf("EOF in '/* ... */' block comment\n");
                          yyleng=0; return VP_EOF_ERROR; }
	YY_BREAK
/* Preprocessor expression */
case YY_STATE_EOF(EXPR):
#line 396 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yyerrorf("EOF in unterminated preprocessor expression");
                          yyleng = 0; return VP_EOF_ERROR; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 398 "../V3PreLex.l"
{ yy_push_state(CMTMODE); yymore(); }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 399 "../V3PreLex.l"
{ FL_FWDC; return VP_COMMENT;}
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 400 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }  /* V3PreProc will push another EXPR state to stack */
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 401 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); return VP_TEXT; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 402 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 403 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 404 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 405 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 406 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 407 "../V3PreLex.l"
{ FL_FWDC; return VP_SYMBOL; }
	YY_BREAK
case 131:
/* rule 131 can match eol */
YY_RULE_SETUP
#line 408 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yytext=(char*)"\n"; yyleng=1; return VP_WHITE; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 409 "../V3PreLex.l"
{ FL_FWDC; return VP_WHITE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 410 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
/* Define arguments (use of a define) */
case 134:
YY_RULE_SETUP
#line 413 "../V3PreLex.l"
{ yy_push_state(CMTMODE); yymore(); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 414 "../V3PreLex.l"
{ FL_FWDC; return VP_COMMENT; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 415 "../V3PreLex.l"
{ FL_FWDC; FL_BRK; }
	YY_BREAK
case YY_STATE_EOF(ARGMODE):
#line 416 "../V3PreLex.l"
{ FL_FWDC; yyerrorf("EOF in define argument list\n");
                          yyleng = 0; return VP_EOF_ERROR; }
	YY_BREAK
case 137:
/* rule 137 can match eol */
YY_RULE_SETUP
#line 418 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yytext=(char*)"\n"; yyleng=1; return VP_WHITE; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 419 "../V3PreLex.l"
{ yy_push_state(STRMODE); yymore(); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 420 "../V3PreLex.l"
{ yy_push_state(QQQMODE); yymore(); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 421 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }  /* Literal text */
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 422 "../V3PreLex.l"
{ FL_FWDC; yy_push_state(STRIFY); return VP_STRIFY; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 423 "../V3PreLex.l"
{ FL_FWDC; LEXP->m_parenLevel++; appendDefValue(yytext, yyleng); FL_BRK; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 424 "../V3PreLex.l"
{ FL_FWDC; LEXP->m_parenLevel--; appendDefValue(yytext, yyleng); FL_BRK; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 425 "../V3PreLex.l"
{ FL_FWDC; LEXP->m_parenLevel++;
                          // Note paren level 0 means before "(" of starting args
                          // Level 1 means "," between arguments
                          // Level 2+ means one inside the () of an argument
                          if (LEXP->m_parenLevel == 1) {  // Starting (
                              if (!VString::isWhitespace(LEXP->m_defValue)) {
                                  yyerrorf("Illegal text before '(' that starts define arguments");
                              }
                          }
                          if (LEXP->m_parenLevel>1) {
                              appendDefValue(yytext, yyleng); FL_BRK;
                          } else {
                              return VP_TEXT;
                        }}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 439 "../V3PreLex.l"
{ FL_FWDC; LEXP->m_parenLevel--;
                          if (LEXP->m_parenLevel>0) {
                              appendDefValue(yytext, yyleng); FL_BRK;
                          } else {
                              yy_pop_state(); return VP_DEFARG;
                        }}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 445 "../V3PreLex.l"
{ FL_FWDC; if (LEXP->m_parenLevel>1) {
                              appendDefValue(yytext, yyleng); FL_BRK;
                          } else {
                              yy_pop_state(); return VP_DEFARG;
                        }}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 450 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }  /* defref in defref - outer macro expands first */
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 451 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }  /* defref in defref - outer macro expands first */
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 452 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }  /* defref in defref - outer macro expands first */
	YY_BREAK
case 150:
#line 454 "../V3PreLex.l"
case 151:
YY_RULE_SETUP
#line 454 "../V3PreLex.l"
{ FL_FWDC; appendDefValue(yytext, yyleng); FL_BRK; }
	YY_BREAK
/* Pragma comments. */
case 152:
YY_RULE_SETUP
#line 457 "../V3PreLex.l"
{ FL_FWDC; LEXP->verilatorCmtLint(yytext + 2, true); return VP_COMMENT; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 458 "../V3PreLex.l"
{ FL_FWDC; LEXP->verilatorCmtLint(yytext + 2, false); return VP_COMMENT; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 459 "../V3PreLex.l"
{ FL_FWDC; LEXP->verilatorCmtLintRestore(); return VP_COMMENT; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 460 "../V3PreLex.l"
{ FL_FWDC; LEXP->verilatorCmtLintSave(); return VP_COMMENT; }
	YY_BREAK
case 156:
/* rule 156 can match eol */
YY_RULE_SETUP
#line 461 "../V3PreLex.l"
{ FL_FWDC; LEXP->verilatorCmtLint(yytext + 2, true); return VP_COMMENT; }
	YY_BREAK
case 157:
/* rule 157 can match eol */
YY_RULE_SETUP
#line 462 "../V3PreLex.l"
{ FL_FWDC; LEXP->verilatorCmtLint(yytext + 2, false); return VP_COMMENT; }
	YY_BREAK
case 158:
/* rule 158 can match eol */
YY_RULE_SETUP
#line 463 "../V3PreLex.l"
{ FL_FWDC; LEXP->verilatorCmtLintRestore(); return VP_COMMENT; }
	YY_BREAK
case 159:
/* rule 159 can match eol */
YY_RULE_SETUP
#line 464 "../V3PreLex.l"
{ FL_FWDC; LEXP->verilatorCmtLintSave(); return VP_COMMENT; }
	YY_BREAK
/* One line comments. */
case 160:
/* rule 160 can match eol */
YY_RULE_SETUP
#line 467 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yytext=(char*)"\n"; yyleng=1; return VP_WHITE; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 468 "../V3PreLex.l"
{ yy_push_state(CMTONEM); yymore(); }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 469 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); return VP_COMMENT; }
	YY_BREAK
/* C-style comments. */
/**** See also DEFCMT */
case 163:
YY_RULE_SETUP
#line 473 "../V3PreLex.l"
{ yy_push_state(CMTMODE); yymore(); }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 474 "../V3PreLex.l"
{ FL_FWDC; yy_pop_state(); return VP_COMMENT; }
	YY_BREAK
case 165:
/* rule 165 can match eol */
YY_RULE_SETUP
#line 475 "../V3PreLex.l"
{ linenoInc(); yymore(); }
	YY_BREAK
case YY_STATE_EOF(CMTMODE):
#line 476 "../V3PreLex.l"
{ FL_FWDC; yyerrorf("EOF in '/* ... */' block comment\n");
                                  yyleng=0; return VP_EOF_ERROR; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 478 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 479 "../V3PreLex.l"
{ yymore(); }
	YY_BREAK
/* Define calls */
/* symbdef prevents normal lex rules from making `\`"foo a symbol {`"foo} instead of a BACKQUOTE */
case 168:
YY_RULE_SETUP
#line 483 "../V3PreLex.l"
{ FL_FWDC; return VP_DEFREF; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 484 "../V3PreLex.l"
{ FL_FWDC; yyleng-=2; return VP_DEFREF_JOIN; }
	YY_BREAK
/* Generics */
case 170:
/* rule 170 can match eol */
YY_RULE_SETUP
#line 487 "../V3PreLex.l"
{ FL_FWDC; linenoInc(); yytext=(char*)"\n"; yyleng=1; return VP_WHITE; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 488 "../V3PreLex.l"
{ FL_FWDC; return VP_EOF; }  /* A "normal" EOF */
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 489 "../V3PreLex.l"
{ FL_FWDC; return VP_SYMBOL; }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 490 "../V3PreLex.l"
{ FL_FWDC; yyleng-=2; return VP_SYMBOL_JOIN; }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 491 "../V3PreLex.l"
{ FL_FWDC; yyleng-=2; return VP_JOIN; }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 492 "../V3PreLex.l"
{ FL_FWDC; return VP_WHITE; }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 493 "../V3PreLex.l"
{ FL_FWDC; FL_BRK; }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 494 "../V3PreLex.l"
{ FL_FWDC; FL_BRK; }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 495 "../V3PreLex.l"
{ FL_FWDC; return VP_TEXT; }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 496 "../V3PreLex.l"
ECHO;
	YY_BREAK
#line 3174 "V3PreLex_pregen.yy.cpp"
case YY_STATE_EOF(CMTONEM):
case YY_STATE_EOF(ENCBASE64):
case YY_STATE_EOF(PASSTHRU):
case YY_STATE_EOF(PRAGMA):
case YY_STATE_EOF(PRAGMAERR):
case YY_STATE_EOF(PRAGMAPRT):
case YY_STATE_EOF(PRAGMAPRTERR):
case YY_STATE_EOF(LIBMODE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */
    static yy_state_type yy_get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 696 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 696 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 695);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

    static void yyunput (int c, char * yy_bp )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void yyrestart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void yy_load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
/* %if-c-only */
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

/* %if-c-only */
	b->yy_input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void yypop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void yyensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

/* %if-c-only */
    static void yy_push_state (int  _new_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_size_t) (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc( new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc(
					(void *) (yy_start_stack), new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(_new_state);
}

/* %if-c-only */
    static void yy_pop_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

/* %if-c-only */
    static int yy_top_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree( (yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 496 "../V3PreLex.l"

// clang-format on

void V3PreLex::pushStateDefArg(int level) {
    // Enter define substitution argument state
    yy_push_state(ARGMODE);
    m_parenLevel = level;
    m_defValue = "";
}

void V3PreLex::pushStateDefForm() {
    // Enter define formal arguments state
    yy_push_state(DEFFPAR);  // First is an optional ( to begin args
    m_parenLevel = 0;
    m_defValue = "";
}

void V3PreLex::pushStateDefValue() {
    // Enter define value state
    yy_push_state(DEFVAL);
    m_parenLevel = 0;
    m_defValue = "";
}

void V3PreLex::pushStateExpr() {
    // Enter preprocessor expression state
    yy_push_state(EXPR);
}

void V3PreLex::pushStateIncFilename() {
    // Enter include <> filename state
    yy_push_state(INCMODE);
    yymore();
}

void V3PreLex::pushStatePassthru() {
    yy_push_state(PASSTHRU);
    yymore();
}

void V3PreLex::setYYDebug(bool on) {
    yy_flex_debug = static_cast<int>(on); }

VPreStream* V3PreLex::newStream(FileLine* fl, V3PreLex* lexp) {
    VPreStream* const streamp = new VPreStream{fl, lexp};
    if (v3Global.opt.debugPreprocPassthru()) streamp->m_lexp->pushStatePassthru();
    return streamp;
}

int V3PreLex::lex() {
    V3PreLex::s_currentLexp = this;  // Tell parser where to get/put data
    // Remember token start location, may be updated by the lexer later
    m_tokFilelinep = curFilelinep();
    return yylex();
}

size_t V3PreLex::inputToLex(char* buf, size_t max_size) {
    // We need a custom YY_INPUT because we can't use flex buffers.
    // Flex buffers are limited to 2GB, and we can't chop into 2G pieces
    // because buffers can't end in the middle of tokens.
    // Note if we switched streams here (which we don't) "buf" would be
    // become a stale invalid pointer.
    //
    VPreStream* streamp = curStreamp();
    if (debug() >= 10) {  // LCOV_EXCL_START
        cout << "-  pp:inputToLex ITL s=" << max_size << " bs=" << streamp->m_buffers.size()
             << endl;
        dumpStack();
    }  // LCOV_EXCL_STOP
    // For testing, use really small chunks
    // if (max_size > 13) max_size=13;
again:
    size_t got = 0;
    // Get from this stream
    while (got < max_size  // Haven't got enough
           && !streamp->m_buffers.empty()) {  // And something buffered
        string front = curStreamp()->m_buffers.front();
        streamp->m_buffers.pop_front();
        size_t len = front.length();
        if (len > (max_size - got)) {  // Front string too big
            len = (max_size - got);
            string remainder = front.substr(len);
            front.resize(len);
            streamp->m_buffers.push_front(remainder);  // Put back remainder for next time
        }
        strncpy(buf + got, front.c_str(), len);
        got += len;
    }
    if (!got) {  // end of stream; try "above" file
        bool again = false;
        string forceOut = endOfStream(again /*ref*/);
        streamp = curStreamp();  // May have been updated
        if (forceOut != "") {
            if (forceOut.length() > max_size) {  // LCOV_EXCL_LINE
                yyerrorf("Output buffer too small for a `line");  // LCOV_EXCL_LINE
            } else {
                got = forceOut.length();
                strncpy(buf, forceOut.c_str(), got);
            }
        } else {
            if (streamp->m_eof) {
                if (yy_flex_debug) cout << "-  EOF\n";
            }
            got = 0;  // 0=EOF/EOS - although got was already 0.
            if (again) goto again;
        }
    }
    if (debug() >= 10) {
        cout << "-  pp::inputToLex  got=" << got << " '" << std::string{buf, got} << "'" << endl;
    }
    return got;
}

string V3PreLex::endOfStream(bool& againr) {
    // Switch to file or next unputString
    againr = false;
    if (yy_flex_debug) {
        cout << "-EOS state=" << curStreamp()->m_termState << " at " << curFilelinep() << endl;
    }
    if (curStreamp()->m_eof) return "";  // Don't delete the final "EOF" stream
    bool exited_file = curStreamp()->m_file;
    if (!exited_file) {
        // Midpoint of stream, just change buffers
        delete curStreamp();
        m_streampStack.pop();  // Must work as size>1; EOF is entry 0
        againr = true;
        return "";
    }
    // Multiple steps because we need FLEX to see ending \n and EOS to end
    // any illegal states, like an unterminated `protected region
    else if (!curStreamp()->m_termState) {
        // First shutdown phase for a file
        // Terminate all files with a newline.  This prevents problems if
        // the user had a define without a terminating newline,
        // otherwise the resumed file's next line would get tacked on.
        // Also makes it likely the `line that changes files comes out
        // immediately.
        curStreamp()->m_termState = 1;
        return "\n";  // Exit old file
    } else if (curStreamp()->m_termState == 1) {
        // Now the EOF - can't be sent with other characters
        curStreamp()->m_termState = 2;
        return "";  // End of file
    } else if (curStreamp()->m_termState == 2) {
        // Now ending `line
        curStreamp()->m_termState = 3;
        return curFilelinep()->lineDirectiveStrg(0);  // THe "2" exit is below
    } else {
        // Final shutdown phase for a stream, we can finally change the
        // current fileline to the new stream
        curStreamp()->m_termState = 0;
        FileLine* const filelinep = curFilelinep();
        delete curStreamp();
        m_streampStack.pop();  // Must work as size>1; EOF is entry 0
        if (curStreamp()->m_eof) {
            // EOF doesn't have a "real" fileline, but a linenumber of 0 from init time
            // Inherit whatever we last parsed so it's more obvious.
            curFilelinep(filelinep);
        }
        // The caller parser remembered the start location for the text we are parsing,
        // but we've discovered there was a file switch along the way, so update it.
        m_tokFilelinep = curFilelinep();
        //
        if (curStreamp()->m_eof) {
            return "";
        } else {
            return curFilelinep()->lineDirectiveStrg(2);  // Reenter resumed file
        }
    }
}

void V3PreLex::initFirstBuffer(FileLine* filelinep) {
    // Called from constructor to make first buffer
    // yy_create_buffer also sets yy_fill_buffer=1 so reads from YY_INPUT
    VPreStream* const streamp = newStream(filelinep, this);
    streamp->m_eof = true;
    m_streampStack.push(streamp);
    //
    m_bufferState = yy_create_buffer(nullptr, YY_BUF_SIZE);
    yy_switch_to_buffer(m_bufferState);
    yyrestart(nullptr);
}

void V3PreLex::scanNewFile(FileLine* filelinep) {
    // Called on new open file.  scanBytesBack will be called next.
    if (streamDepth() > V3PreProc::DEFINE_RECURSION_LEVEL_MAX) {
        // The recursive `include in VPreProcImp should trigger first
        yyerrorf("Recursive `define or other nested inclusion");
        curStreamp()->m_eof = true;  // Fake it to stop recursion
    } else {
        VPreStream* const streamp = newStream(filelinep, this);
        m_tokFilelinep = curFilelinep();
        streamp->m_file = true;
        scanSwitchStream(streamp);
    }
}

void V3PreLex::scanBytes(const string& str) {
    // Note buffers also appended in ::scanBytesBack
    // Not "m_buffers.push_front(std::string{strp,len})" as we need a `define
    // to take effect immediately, in the middle of the current buffer
    // Also we don't use scan_bytes that would set yy_fill_buffer
    // which would force Flex to bypass our YY_INPUT routine.
    if (streamDepth() > V3PreProc::DEFINE_RECURSION_LEVEL_MAX) {
        // More streams if recursive `define with complex insertion
        // More buffers mostly if something internal goes funky
        yyerrorf("Recursive `define or other nested inclusion");
        curStreamp()->m_eof = true;  // Fake it to stop recursion
    } else {
        VPreStream* const streamp = newStream(curFilelinep(), this);
        streamp->m_buffers.push_front(str);
        scanSwitchStream(streamp);
    }
}

void V3PreLex::scanSwitchStream(VPreStream* streamp) {
    curStreamp()->m_buffers.push_front(currentUnreadChars());
    m_streampStack.push(streamp);
    yyrestart(nullptr);
}

void V3PreLex::scanBytesBack(const string& str) {
    // Initial creation, that will pull from YY_INPUT==inputToLex
    // Note buffers also appended in ::scanBytes
    if (VL_UNCOVERABLE(curStreamp()->m_eof)) yyerrorf("scanBytesBack not under scanNewFile");
    curStreamp()->m_buffers.push_back(str);
}

string V3PreLex::currentUnreadChars() {
    // WARNING - Peeking at internals
    ssize_t left = (yy_n_chars - (yy_c_buf_p - currentBuffer()->yy_ch_buf));
    if (left > 0) {  // left may be -1 at EOS
        *(yy_c_buf_p) = (yy_hold_char);
        return std::string(yy_c_buf_p, left);  // () narrowing conversion
    } else {
        return "";
    }
}

YY_BUFFER_STATE V3PreLex::currentBuffer() {
    return YY_CURRENT_BUFFER;
}

int V3PreLex::currentStartState() const {
    return YY_START;
}

void V3PreLex::lineDirective(const char* textp) {
    curFilelinep()->lineDirective(textp, m_enterExit /*ref*/);
    // Make sure we have a dependency on whatever file was specified
    V3File::addSrcDepend(curFilelinep()->filename());
}

void V3PreLex::warnBackslashSpace() {
    // Make fileline highlight the specific backslash and space
    curFilelinep()->v3warn(
        BSSPACE, "Backslash followed by whitespace, perhaps the whitespace is accidental?");
}

void V3PreLex::dumpSummary() {  // LCOV_EXCL_START
    cout << "-  pp::dumpSummary  curBuf=" << cvtToHex(currentBuffer());
#ifdef FLEX_DEBUG  // Else peeking at internals may cause portability issues
    ssize_t left = (yy_n_chars - (yy_c_buf_p - currentBuffer()->yy_ch_buf));
    cout << " left=" << std::dec << left;
#endif
    cout << endl;
}  // LCOV_EXCL_STOP

void V3PreLex::dumpStack() {  // LCOV_EXCL_START
    // For debug use
    dumpSummary();
    std::stack<VPreStream*> tmpstack = LEXP->m_streampStack;
    while (!tmpstack.empty()) {
        const VPreStream* const streamp = tmpstack.top();
        cout << "-    bufferStack[" << cvtToHex(streamp)
             << "]: " << " at=" << streamp->m_curFilelinep << " nBuf=" << streamp->m_buffers.size()
             << " size0=" << (streamp->m_buffers.empty() ? 0 : streamp->m_buffers.front().length())
             << (streamp->m_eof ? " [EOF]" : "") << (streamp->m_file ? " [FILE]" : "") << endl;
        tmpstack.pop();
    }
}  // LCOV_EXCL_STOP

string V3PreLex::cleanDbgStrg(const string& in) {
    string result = in;
    string::size_type pos;
    while ((pos = result.find('\n')) != string::npos) result.replace(pos, 1, "\\n");
    while ((pos = result.find('\r')) != string::npos) result.replace(pos, 1, "\\r");
    return result;
}

void V3PreLex::unused() {
    if (VL_UNCOVERABLE(false)) {  // LCOV_EXCL_START
        // Prevent unused warnings
        yy_top_state();
        yyerror((char*)"");
    }  // LCOV_EXCL_STOP
}

void V3PreLex::verilatorCmtLintSave() {
    m_lexLintState.push_back(*curFilelinep());
}
void V3PreLex::verilatorCmtLintRestore() {
    // No error here on restore without save - the verilog.y parse will report as appropriate
    if (m_lexLintState.empty()) return;
    curFilelinep()->warnStateFrom(m_lexLintState.back());
    m_lexLintState.pop_back();
}
void V3PreLex::verilatorCmtLint(const char* textp, bool turnOff) {
    const char* sp = textp;
    while (*sp && std::isspace(*sp)) ++sp;
    while (*sp && !std::isspace(*sp)) ++sp;  // "verilator"
    while (*sp && std::isspace(*sp)) ++sp;
    while (*sp && !std::isspace(*sp)) ++sp;  // "lint_on/lint_off"
    while (*sp && std::isspace(*sp)) ++sp;
    string msg = sp;
    for (auto pos = msg.begin(); pos != msg.end(); ++pos) {
        if (std::isspace(*pos) || *pos == '*') {
            msg.erase(pos, msg.end());
            break;
        }
    }
    // No warnings on bad warning codes - the verilog.y parse will report as appropriate
    curFilelinep()->warnOffParse(msg, turnOff);
}

/*###################################################################
 * Local Variables:
 * mode: C++
 * End:
 */

